#
# spec file for package libeXosip2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname libeXosip2-12

Name:           libeXosip2
Version:        5.0.0
Release:        lp150.2.1
Summary:        Extended osip2 library
License:        GPL-2.0-only
Group:          Productivity/Networking/Other
Url:            http://savannah.nongnu.org/projects/exosip/
Source:         http://download.savannah.nongnu.org/releases/exosip/libexosip2-%{version}.tar.gz
Patch0:         openssl110-fix.patch
BuildRequires:  glibc-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libosip2) >= 5.0.0
BuildRequires:  pkgconfig(openssl)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Extended library for the osip2 protocol.

%package -n %{soname}
Summary:        Extended osip2 library
Group:          System/Libraries
Provides:       libeXosip2 = %{version}

%description -n %{soname}
Extended library for the osip2 protocol.

%package devel
Summary:        Extended osip2 library
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}
Requires:       glibc-devel
Requires:       pkgconfig(libosip2)
Requires:       pkgconfig(openssl)
Provides:       %{soname}-devel = %{version}

%description devel
Extended library for the osip2 protocol.

%prep
%setup -q -n libexosip2-%{version}
%if 0%{?suse_version} >= 1330 
%patch0 -p0
%endif

%build
%configure \
  --disable-static \
  --disable-debug
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{soname} -p /sbin/ldconfig

%postun -n %{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/sip_reg

%files -n %{soname}
%defattr(-,root,root)
%{_libdir}/lib*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/eXosip2/*.h
%dir %{_includedir}/eXosip2
%{_libdir}/lib*.so

%changelog
* Fri Apr 20 2018 hpj@urpla.net
- apply openssl110-fix.patch for Leap >= 15.0 only
* Thu Dec 28 2017 fisiu@opensuse.org
- Update to 5.0.0:
  * major API update: add a new parameter to eXosip_call_build_prack in order to create the PRACK
    for this specific response and not for the latest.
  * major API update: removal of eX_refer.h API. REFER are now handled with subscriptions APIs.
  eXosip_refer_build_request removed
  eXosip_refer_send_request removed
  * major API update: subscription now handle both SUBSCRIBE and REFER with the same APIs:
  eXosip_subscription_build_initial_refer ADDED
  eXosip_subscribe_build_initial_request renamed eXosip_subscription_build_initial_subscribe
  eXosip_subscribe_send_initial_request renamed eXosip_subscription_send_initial_request
  eXosip_subscribe_build_refresh_request renamed eXosip_subscription_build_refresh_request
  eXosip_subscribe_send_refresh_request renamed eXosip_subscription_send_refresh_request
  eXosip_subscribe_remove renamed eXosip_subscription_remove
  EXOSIP_IN_SUBSCRIPTION_* and EXOSIP_SUBSCRIPTION_* events may now relate to REFER subscription.
  * major API change: eXosip_automatic_refresh is obsolete and has been removed.
  only use eXosip_automatic_action instead
  * API update:
  eXosip_options_send_request returns a positive transaction id (tid) on success.
  eXosip_publish returns a positive transaction id (tid) on success.
  note: eXosip_message_send_request was already returing the transaction id (tid) on success.
  * new API options:
  EXOSIP_OPT_REMOVE_PREROUTESET: to keep Route Set
  EXOSIP_OPT_SET_SIP_INSTANCE: define +sip.instance parameter in Contact headers
  EXOSIP_OPT_ENABLE_USE_EPHEMERAL_PORT: option to use/not use ephemeral port in Contact.
  EXOSIP_OPT_ENABLE_REUSE_TCP_PORT: option to reuse port.
  EXOSIP_OPT_AUTO_MASQUERADE_CONTACT: option to enable automatic masquerading for Contact headers.
  EXOSIP_OPT_UDP_LEARN_PORT: obsolete and will be removed in the future.
  EXOSIP_OPT_SET_DEFAULT_CONTACT_DISPLAYNAME: define a display name to be added in Contact headers
  * new API options: (high load traffic use-case: DO NOT USE FOR COMMON USAGE)
  EXOSIP_OPT_SET_MAX_MESSAGE_TO_READ: set the number of message to read at once for each network processing.
  EXOSIP_OPT_SET_MAX_READ_TIMEOUT: set the period in nano seconds during we read for sip message.
  EXOSIP_OPT_GET_STATISTICS: retreive numerous statistics.
  * rewrite/update autotools and ./configure options
  - -enable-pthread=[autodetect|force]
  autodetect POSIX threads or force -DHAVE_PTHREAD [default=autodetect]
  - -enable-semaphore=[autodetect|semaphore|sysv]
  select your prefered semaphore [default=autodetect].
  * fix bug when reading sip message longuer than 8000 over UDP and TLS.
  * improve eXosip_add_authentication_info to avoid duplicate credentials
  * if a SUBSCRIBE is rejected, the context will be released automatically
  * add failover after a DNS failure.
  * fallback to SRV even if we receive a NOTFOUND reply for NAPTR.
  * fix route set with strict router.
  * rename usage of -DHAVE_CARES_H into -DHAVE_ARES_H real name of header.
  * remove warnings mainly related to socket API (getnameinfo/bind/accept/recv/connect/sendto)
  * rewrite all loop using iterator to improve performance (useful for high load traffic)
  * rewrite Via and Contact management: both will now contains the IP of the real network interface
  instead of the default one.
  * improve NAPTR failover, more reliable // add failover for 503 answer
  * improve interval to force REGISTER refresh upon network error and failover.
  * improve TCP socket management
  * add a callback to simplify/optimize/accelerate usage of wakelocks in android application using exosip2.
  * improve TLS, add TLSv1.1, TLSv1.2, disable weak cipher (FREAK) and enable ECDHE cipher.
  * add support for SNI tls extension (openssl 1.0.2)
  * add try/except on windows to catch possible missing qwave (windows server)
  * implement a timeout (32 seconds) for establishing a TCP and TLS connection.
  * if a connection is failing, report the failure asap.
  * fix memory leak in eXosip_call_get_referto
  * remove extra connect on socket for TCP and TLS (not allowed for tcp stream)
  * fix to correctly discard INVITE retransmission with same branch received after original INVITE was replied
  * add WSACleanup for each WSAStartup call (windows)
  * do not include contact in BYE and CANCEL
  * fix to use sips when appropriate (in Contact)
  * fix to avoid handling negative content-length
  * do not start naptr for incoming transactions.
  * fix bug when rseq is empty but exist
  * add support for QOS on windows.
  * improve connection handling/failure detection, keep alive options, in TLS, TCP, UDP.
  * update static IDs (cid/did/rid/pid) to use range from 0 to INT_MAX to avoid possible collision
  * other minor updates.
- Drop libeXosip2-sslverifypaths.patch: fixed upstream.
- Add openssl110-fix.patch: fix build with openssl 1.1.0.
* Sun May 25 2014 fisiu@opensuse.org
- Update to 4.1.0:
  * improve timer and use UPDATE if advertised, INVITE otherwise.
  * improve PRACK support.
  * option to disable automatic BYE answer.
  * option to enable/disable IPv6 per eXosip_t instance.
  * option to disable DNS cache.
  * improve network support for several eXosip_t instance.
    keepalive setting is per instance.
    ipv4/ipv6 setting is per instance.
    improve network setting to avoid conflict upon transport change.
  * fix tcp and tls connect() for slow connection.
  * use TCP_NODELAY on more platform.
  * use Authorization header for 401 // simplify authentication code.
  * minor expires for REGISTER improvments.
  * copy call-info over SUBSCRIBE refresh.
  * allow more TLS error if verification is disabled.
  * fix if NO NAPTR is availble.
  * add support for Windows Phone 8.
  * fix to use cache for TCP and TLS.
  * fix possible leaks on implementation errors.
  * add TSC experimental support.
- eXosip2 (4.0.0)
  * modify configuration APIs to use eXosip_set_option
  * fix bug: do not create new PRACK if it already exist for an answer.
  * update to latest osip // test time compensation for android.
  * use ephemaral port in standard TCP and TLS version.
  * return tid number so that we can match the response event.
  * use system independant time for osip_gettimeofday on unix platform.
  * major API update: several "struct eXosip_t" can be
    handled at the same time. This can be used to have several
    transport layer running at the same time.
  * many tiny other change.
- Rebase libeXosip2-sslverifypaths.patch.
* Mon Apr 28 2014 meissner@suse.com
- libeXosip2-sslverifypaths.patch: set default SSL verify locations (bnc#871099)
- build with -O2 (--disable-debug)
* Fri Jan 25 2013 jengelh@inai.de
- Remove redundant tags/sections from specfile
* Sun Jan 16 2011 seife+obs@b1-systems.com
- update to version 3.5.0
  * a lot of minor change/fix/improvments, sorry for not being
    able to have an history here...
- eXosip2 (3.4.0)
  * handle keep alive for TCP/TLS.
  * fix when receiving additionnal CRLF on reliable transport.
  * modification to allow non-blocking socket for reliable transport. (TLS/TCP)
  * fix tag issue with application where tag is missing.
  * fix Contact header in request within dialog for non-udp protocol.
  * remove 481 auto answer for unsolicited NOTIFY.
  * fix static id range.
  * initial code for TCP fragmentation.
  * osip_list prototypes and warnings fix
  * fix transport matching for redirection using other transport than udp
- eXosip2 (3.3.0)
  * Fix when 200ok include a contact with an empty line parameter.
  * Fix for replaces header longuer than 256 char.
  * Fix SRV record with more than 10 answers.
  * Sort SRV record.
  * Option to disable NAPTR requests.
- eXosip2 (3.2.0)
  * Improve TLS support and add an API for ssl information & files.
  * return new error code for all API.
  * remove automatic answers to PRACK. (must be done in application now)
  * remove automatically outgoing non established susbscriptions.
- packaging stuff:
  * fix spelling errors in descriptions, other rpmlint warnings
  * rename libeXosip2-4 to libeXosip2-6 (changed SONAME)
* Wed Apr  2 2008 hvogel@suse.de
- update to version 3.1.0
  * add AKA authentication
  * improve compliance & flexibility
  * fix building SUBSCRIBE refresh
  * fix compliance issue with refer-to to-tag/from-tag parameters.
  * fix bug for retransmissions or ACK with proxy that resolve
    to several IP.
  * handle the "expires" parameter to update registration interval.
  * handle the "expires" parameter to update publication interval.
  * handle automatically publish refresh,
    and some error codes (423).
* Thu Feb 28 2008 ro@suse.de
- fix build with current libosip2 (MD5... -> osip_MD5...)
* Thu Jan 10 2008 mskibbe@suse.de
- use --disable-static
- detaillize files section
* Tue Dec 18 2007 mskibbe@suse.de
- create package
